"""
Generates the partitioned Zeichner dataset used in the experiments described in:

"Lexical Inference over Multi-Word Predicates: A Distributional Approach",
Omri Abend, Shay B. Cohen and Mark Steedman, ACL 2014.

You'll need to download the Zeichner corpus from "http://u.cs.biu.ac.il/~nlp/?page_id=133", unzip it and run this script on the data files (see below).

Arguments:
==========
<entailing examples file>: the file "entailingAnnotations.txt" from the Zeichner et al. corpus
<nonentailing examples file>: the file "nonEntailingAnnotations.txt" from the Zeichner et al. corpus
<output training instances>: the output file with the training instances. The first field is 'True' for entailing pairs and 'False' for non-entailing ones.
<output test instances>: the output file with the test instances. The first field is 'True' for entailing pairs and 'False' for non-entailing ones.
"""

import sys

def read_line_numbers(filename):
    f = open(filename)
    L = []
    for line in f:
        L.append(int(line.strip()))
    return L

def get_instances(entailing_fn, nonentailing_fn):
    entailing = []
    f = open(entailing_fn)
    f.readline()  # getting rid of the header
    for line in f:
        entailing.append('True\t'+line.strip())
    f.close()
    nonentailing = []
    f = open(nonentailing_fn)
    f.readline()
    for line in f:
        nonentailing.append('False\t'+line.strip())
    f.close()
    return entailing + nonentailing

def get_indices(num_instances, train_indices_temp, remove_indicesL):
    instance_list = [x for x in range(num_instances) if x not in remove_indicesL]
    train_indicesL = [ind for ind,x in enumerate(instance_list) if x in train_indices_temp]
    test_indicesL = [ind for ind,x in enumerate(instance_list) if x not in train_indices_temp]
    return train_indicesL, test_indicesL

#########
# MAIN 
#########

TRAIN_INDICES = read_line_numbers('train_indices')
REMOVE_INDICES = read_line_numbers('remove_instances')

if len(sys.argv) != 5:
    sys.stderr.write('Usage: python get_instances.py <entailing examples file> <nonentailing examples file> <output training instances> <output test instances>'+'\n')
    sys.exit(-1)

instances = get_instances(sys.argv[1],sys.argv[2])
if len(instances) != 6567:
    sys.stderr.write('Error: incorrect number of instances. Aborting\n')
    sys.exit(-1)
    
#train_indices, test_indices = get_indices(len(instances), TRAIN_INDICES, REMOVE_INDICES)

f_training = open(sys.argv[3],'w')
f_test = open(sys.argv[4],'w')
for ind,instance in enumerate(instances):
    if ind in REMOVE_INDICES:
        continue
    elif ind in TRAIN_INDICES:
        f_training.write(instance+'\n')
    else:
        f_test.write(instance+'\n')
        

f_training.close()
f_test.close()
        
